/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.definition;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.ow2.orchestra.definition.activity.Exit;
import org.ow2.orchestra.facade.exception.BpelFaultException;
import org.ow2.orchestra.runtime.BpelExecution;
import org.ow2.orchestra.util.Misc;

/**
 * @author S. Ali Tokmen
 */
public class FaultHandlerThatExits extends ExceptionHandler {

  private static final long serialVersionUID = 2305022461357079192L;

  private static final Logger LOG = Logger.getLogger(FaultHandlerThatExits.class.getName());

  @Override
  public boolean matches(final Class< ? > exceptionClass) {
    return BpelFaultException.class.isAssignableFrom(exceptionClass);
  }

  @Override
  protected void executeHandler(final BpelExecution execution, final Exception exception,
    final CompositeElement processElementImpl) {
    Misc.fastDynamicLog(FaultHandlerThatExits.LOG, Level.FINEST,
        "Exception rethrown, exiting process with execution %s", execution);

    final Exit exit = new Exit();
    final BpelExecution bpelExecution = execution;
    exit.executeActivity(bpelExecution);
  }
}
