/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.definition.element;

import org.ow2.orchestra.util.BpelXmlUtil;
import org.ow2.orchestra.util.Misc;
import org.ow2.orchestra.util.XmlUtil;
import org.ow2.orchestra.var.MessageVariable;
import org.ow2.orchestra.wsdl.WsdlsInfos;
import org.w3c.dom.Document;

import javax.wsdl.Part;
import javax.xml.namespace.QName;
import java.util.HashMap;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * declaration of a variable in a bpel process.
 *
 * @author Charles Souillard, Tom Baeyens
 */
public class Variable {

  private static final Logger LOG = Logger.getLogger(Variable.class.getName());

  protected long dbid;
  protected int dbversion;

  /**
   * messageType attribute of this variable.
   */
  protected QName messageType;

  /**
   * xmlType attribute of this variable.
   */
  protected QName xmlType;

  /**
   * element attribute of this variable.
   */
  protected QName element;

  protected Map<String, PartDefinition> messageParts = new HashMap<String, PartDefinition>();

  /**
   * Virtual copy to initialized the variable if it has an inline from-spec.
   */
  protected Copy virtualCopy;

  protected String name;

  public static final String OUTBOUND_ANONYMOUS_WSDL_MESSAGE_NAME = "ORCHESTRA_4_OUTBOUND_WSDL_MESSAGE";

  public static final String INBOUND_ANONYMOUS_WSDL_MESSAGE_NAME = "ORCHESTRA_4_INBOUND_WSDL_MESSAGE";

  protected Document defaultValue;


  /**
   *
   */
  public Variable() {
  }

  public Copy getVirtualCopy() {
    return this.virtualCopy;
  }

  public QName getElement() {
    return this.element;
  }

  public QName getMessageType() {
    return this.messageType;
  }

  public String getName() {
    return this.name;
  }

  public QName getXmlType() {
    return this.xmlType;
  }

  public void setVirtualCopy(final Copy virtualCopy) {
    this.virtualCopy = virtualCopy;
  }

  public void setElement(final QName element) {
    this.element = element;
  }

  public void setMessageType(final QName messageType) {
    this.messageType = messageType;
  }

  public void setName(final String name) {
    this.name = name;
  }

  public void setXmlType(final QName type) {
    this.xmlType = type;
  }


  /**
   * @param wsdlsInfos the defaultValue to set
   */
  public void initDefaultValue(final WsdlsInfos wsdlsInfos) {
    if (this.getMessageType() != null) {
      final javax.wsdl.Message message =
              wsdlsInfos.getMessage(this.getMessageType());
      if (message != null) {
        this.defaultValue = new MessageVariable(message).getPartsAsDocument();
        for (final Object part : message.getOrderedParts(null)) {
          final Part wsdlPart = (Part) part;
          final PartDefinition partDefinition = new PartDefinition(wsdlPart.getTypeName(), wsdlPart.getElementName());
          this.messageParts.put(wsdlPart.getName(), partDefinition);
        }
      }
    } else if (this.getXmlType() != null) {
      this.defaultValue = BpelXmlUtil.createDefaultElement().getOwnerDocument();
    } else if (this.getElement() != null) {
      this.defaultValue = XmlUtil.getDocumentWithOneElement(this.getElement()).getOwnerDocument();
    } else {
      Misc.fastDynamicLog(Variable.LOG, Level.WARNING,
              "initializeXmlType : variable '" + this.getName()
                      + "' is neither a type nor an element... : this case is forbiden");
    }
  }

  /**
   * @return the defaultValue
   */
  public Document getDefaultValue() {
    return this.defaultValue;
  }


  /**
   * @return the messageParts
   */
  public Map<String, PartDefinition> getMessageParts() {
    return this.messageParts;
  }

}
