/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.env.binding;

import org.ow2.orchestra.env.descriptor.ContextTypeRefDescriptor;
import org.ow2.orchestra.env.descriptor.FalseDescriptor;
import org.ow2.orchestra.env.descriptor.IntegerDescriptor;
import org.ow2.orchestra.env.descriptor.ObjectDescriptor;
import org.ow2.orchestra.env.descriptor.TransactionRefDescriptor;
import org.ow2.orchestra.env.descriptor.TrueDescriptor;
import org.ow2.orchestra.services.jobexecutor.JobDbSession;
import org.ow2.orchestra.services.jobexecutor.JobExecutorMessageSession;
import org.ow2.orchestra.util.XmlUtil;
import org.ow2.orchestra.xml.Parse;
import org.ow2.orchestra.xml.Parser;
import org.w3c.dom.Element;

/**
 * parses a descriptor for creating a {@link org.ow2.orchestra.persistence.db.MessageSession}.
 *
 * See schema docs for more details.
 *
 * @author Tom Baeyens
 */
public class MessageSessionBinding extends WireDescriptorBinding {

  public MessageSessionBinding() {
    super("message-session");
  }

  public Object parse(final Element element, final Parse parse, final Parser parser) {
    final ObjectDescriptor objectDescriptor = new ObjectDescriptor();

    objectDescriptor.setClassName(JobExecutorMessageSession.class.getName());
    objectDescriptor.addInjection("transaction",
        new TransactionRefDescriptor());
    objectDescriptor.addInjection("jobDbSession", new ContextTypeRefDescriptor(
        JobDbSession.class));
    if (element.hasAttribute("retries")) {
      final String retriesText = element.getAttribute("retries");
      try {
        final Integer retries = Integer.valueOf(retriesText);
        objectDescriptor.addInjection("defaultRetries", new IntegerDescriptor(retries));
      } catch (final NumberFormatException e) {
        parse.addProblem("couldn't parse retries " + retriesText, element.getAttributeNode("retries"));
      }
    }
    if (element.hasAttribute("use-fair-scheduling")) {
      final String useFairSchedulingText = element.getAttribute("use-fair-scheduling");
      final Boolean useFairScheduling = XmlUtil.parseBooleanValue(useFairSchedulingText);
      if (useFairScheduling != null) {
        if (useFairScheduling.booleanValue()) {
          objectDescriptor.addInjection("useFairScheduling", new TrueDescriptor());
        } else {
          objectDescriptor.addInjection("useFairScheduling", new FalseDescriptor());
        }
      } else {
        parse.addProblem("couldn't parse use-fair-scheduling " + useFairSchedulingText,
            element.getAttributeNode("use-fair-scheduling"));
      }
    }

    return objectDescriptor;
  }
}
