/**
 * Copyright (C) 2008 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.def.full.impl;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.xml.namespace.QName;

import org.ow2.orchestra.facade.CopyUtil;
import org.ow2.orchestra.facade.def.ProcessState;
import org.ow2.orchestra.facade.def.ProcessStateUpdate;
import org.ow2.orchestra.facade.def.full.ProcessFullDefinition;
import org.ow2.orchestra.facade.def.impl.ProcessDefinitionImpl;
import org.ow2.orchestra.facade.def.impl.ProcessStateUpdateImpl;
import org.ow2.orchestra.facade.runtime.ActivityType;
import org.ow2.orchestra.facade.uuid.ProcessDefinitionUUID;

/**
 *
 * @author Gael Lalire
 */
public class ProcessFullDefinitionImpl extends ScopeActivityFullDefinitionImpl implements ProcessFullDefinition {

  private static final long serialVersionUID = 2606705701938051916L;

  protected String nameSpace;

  protected String expressionLanguage;
  protected String queryLanguage;

  protected Date deployedDate;
  protected Date undeployedDate;

  protected ProcessState state;

  protected List<ProcessStateUpdate> stateUpdates;

  protected Map<String, byte[]> resources;

  protected int version;

  protected ProcessFullDefinitionImpl() {
    super();
  }

  /**
   * @param uuid uuid of process definition
   * @param nameSpace nameSpace of the process
   * @param name name of process
   */
  public ProcessFullDefinitionImpl(final ProcessDefinitionUUID uuid, final String nameSpace, final String name,
    final String queryLanguage, final String expressionLanguage, final Date deployedDate) {
    super(uuid, uuid, name);
    this.nameSpace = nameSpace;
    this.queryLanguage = queryLanguage;
    this.expressionLanguage = expressionLanguage;
    this.deployedDate = deployedDate;
    this.stateUpdates = new ArrayList<ProcessStateUpdate>();
    this.setState(deployedDate, ProcessState.ACTIVE);
  }

  public ProcessFullDefinitionImpl(final ProcessFullDefinition src) {
    super(src);
    this.nameSpace = src.getNameSpace();
    this.expressionLanguage = src.getExpressionLanguage();
    this.queryLanguage = src.getQueryLanguage();
    this.deployedDate = src.getDeployedDate();
    this.undeployedDate = src.getUndeployedDate();
    this.state = src.getState();
    this.stateUpdates = CopyUtil.copyList(src.getStateUpdates());
    this.version = src.getVersion();
    this.resources = new HashMap<String, byte[]>(src.getProcessResources());
  }

  @Override
  public ProcessDefinitionUUID getUUID() {
    return this.processDefinitionUUID;
  }

  public String getNameSpace() {
    return this.nameSpace;
  }

  public String getExpressionLanguage() {
    return this.expressionLanguage;
  }

  public String getQueryLanguage() {
    return this.queryLanguage;
  }

  public Date getDeployedDate() {
    return this.deployedDate;
  }

  public Date getUndeployedDate() {
    return this.undeployedDate;
  }

  public void setUndeployedDate(final Date undeployedDate) {
    this.undeployedDate = undeployedDate;
    this.setState(undeployedDate, ProcessState.UNDEPLOYED);
  }

  @Override
  public ProcessDefinitionImpl copy() {
    return new ProcessDefinitionImpl(this);
  }

  @Override
  public ProcessFullDefinitionImpl fullCopy() {
    return new ProcessFullDefinitionImpl(this);
  }

  @Override
  public ActivityType getType() {
    return ActivityType.PROCESS;
  }

  public QName getQName() {
    return new QName(this.getNameSpace(), this.getName());
  }

  public ProcessState getState() {
    return this.state;
  }

  public List<ProcessStateUpdate> getStateUpdates() {
    return this.stateUpdates;
  }

  public int getVersion() {
    return this.version;
  }


  public void setVersion(final int version) {
    this.version = version;
  }

  public void setState(final Date date, final ProcessState newState) {
    this.state = newState;
    this.stateUpdates.add(new ProcessStateUpdateImpl(date, newState));
  }

  public Map<String, byte[]> getProcessResources() {
    return this.resources;
  }

  public Collection<String> getProcessResourceNames() {
    return this.resources.keySet();
  }

  public void setProcessResources(final Map<String, byte[]> resources) {
    this.resources = new HashMap<String, byte[]>(resources);
  }
}
