/**
 * Copyright (C) 2008 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.runtime.full.impl;

import java.util.Date;

import org.ow2.orchestra.facade.runtime.VariableUpdate;
import org.ow2.orchestra.facade.runtime.full.ScopeActivityFullInstance;
import org.ow2.orchestra.facade.runtime.impl.VariableUpdateImpl;
import org.ow2.orchestra.facade.uuid.ActivityInstanceUUID;
import org.ow2.orchestra.util.Misc;
import org.ow2.orchestra.util.XmlUtil;
import org.ow2.orchestra.var.MessageVariable;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 *
 * @author Gael Lalire
 */
public class VariableUpdateFullImpl implements VariableUpdate {

  private static final long serialVersionUID = 4978973329065042473L;

  // for persistence
  protected long dbid;

  protected int index;

  protected ScopeActivityFullInstance scopeActivityFullInstance;

  protected ActivityInstanceUUID activityUUID;

  protected Date date;

  protected String name;

  protected boolean isMessage = false;

  protected Document xmlValue;

  protected VariableUpdateFullImpl() {
  }

  public VariableUpdateFullImpl(final VariableUpdate record, final ScopeActivityFullInstance scopeActivityFullInstance) {
    this(
        scopeActivityFullInstance,
        record.getActivityUUID(),
        new Date(record.getDate().getTime()),
        record.getName(),
        record.getValue());
  }

  public VariableUpdateFullImpl(
      final ScopeActivityFullInstance scopeActivityFullInstance,
      final ActivityInstanceUUID activityUUID,
      final Date date,
      final String name,
      final Object value) {
    this.scopeActivityFullInstance = scopeActivityFullInstance;
    this.activityUUID = activityUUID;
    this.date = new Date(date.getTime());
    this.name = name;
    if (value != null) {
      if (value instanceof MessageVariable) {
        this.xmlValue = ((MessageVariable) value).duplicate().getPartsAsDocument();
        this.isMessage = true;
      } else if (value instanceof Element) {
        this.xmlValue = XmlUtil.getNewDocument();
        final Node n = this.xmlValue.importNode((Node) value, true);
        this.xmlValue.appendChild(n);
        this.isMessage = false;
      } else {
        Misc.unreachableStatement("unknow variable type");
      }
    }
  }

  public ActivityInstanceUUID getActivityUUID() {
    return this.activityUUID;
  }

  public Date getDate() {
    return this.date;
  }

  public String getName() {
    return this.name;
  }

  public Object getValue() {
    if (this.isMessage) {
      return new MessageVariable(this.xmlValue);
    }
    if (this.xmlValue == null) {
      return null;
    }
    return this.xmlValue.getDocumentElement();
  }

  @Override
  public String toString() {
    return "Update " + this.name + " at " + this.date + " by " + this.activityUUID + " to value [" + this.getValue() + "]";
  }

  public VariableUpdate copy() {
    return new VariableUpdateImpl(this);
  }


  /**
   * @param index the index to set
   */
  public void setIndex(final int index) {
    this.index = index;
  }
}
