/**
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.jmx.commands;

import org.ow2.orchestra.definition.BpelProcess;
import org.ow2.orchestra.env.Environment;
import org.ow2.orchestra.facade.exception.OrchestraWrapperException;
import org.ow2.orchestra.facade.exception.ProcessNotFoundException;
import org.ow2.orchestra.facade.uuid.ProcessDefinitionUUID;
import org.ow2.orchestra.services.commands.Command;
import org.ow2.orchestra.services.itf.Repository;
import org.ow2.orchestra.util.EnvTool;

public final class ActivateProcessCommand implements Command<Boolean> {

  private static final long serialVersionUID = -1626991011601734973L;

  private final ProcessDefinitionUUID pduuid;
  /**
   * @param pduuid
   */
  public ActivateProcessCommand(final ProcessDefinitionUUID pduuid) {
    this.pduuid = pduuid;
  }

  public Boolean execute(final Environment environment) {
    if (this.pduuid == null) {
      throw new IllegalArgumentException("Process definition uuid is null");
    }
    final Repository repository = EnvTool.getRepository();
    final BpelProcess bpelProcess = repository.getProcess(this.pduuid);
    if (bpelProcess == null) {
      throw new OrchestraWrapperException(new ProcessNotFoundException(this.pduuid));
    }
    final BpelProcess activeProcess = repository.getActiveProcess(bpelProcess.getQName());
    if (!bpelProcess.equals(activeProcess)) {
      // Retire all other process versions
      if (activeProcess != null) {
        repository.retireProcess(activeProcess);
      }
      // activate this version
      repository.activateProcess(bpelProcess);
      return Boolean.TRUE;
    } else {
      // version already active: do nothing
      return Boolean.FALSE;
    }
  }
}
