/**
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.jmx.commands;

import java.util.ArrayList;
import java.util.List;

import org.ow2.orchestra.env.Environment;
import org.ow2.orchestra.facade.data.runtime.JobData;
import org.ow2.orchestra.facade.uuid.ActivityInstanceUUID;
import org.ow2.orchestra.facade.uuid.ProcessInstanceUUID;
import org.ow2.orchestra.runtime.BpelExecution;
import org.ow2.orchestra.services.commands.Command;
import org.ow2.orchestra.services.job.Job;
import org.ow2.orchestra.util.EnvTool;

/**
 * @author Guillaume Porcher
 *
 */
public final class FindJobsWithExceptionCommand implements Command<List<JobData>> {

  private static final long serialVersionUID = 8597363585801154662L;

  public List<JobData> execute(final Environment environment) {
    final List<JobData> result = new ArrayList<JobData>();
    // Get the list of dead jobs from the repository
    final List<Job> jobs = EnvTool.getRepository().findJobsWithException();
    // For each job, create a jobData
    if (jobs != null) {
      for (final Job job : jobs) {
        // Get UUIDs from BpelExecution
        ActivityInstanceUUID activityInstanceUUID = null;
        ProcessInstanceUUID processInstanceUUID = null;
        if (job.getExecution() != null) {
          final BpelExecution jobExecution = job.getExecution();
          activityInstanceUUID = jobExecution.getActivityInstanceUUID();
          processInstanceUUID = jobExecution.getProcessInstance().getProcessInstanceUUID();
        }
        // create JobData
        final JobData jobData = new JobData(
            job.getClass().getName(),
            job.getDbid(),
            job.isSuspended(),
            job.getDueDate(),
            job.getException(),
            job.getRetries(), activityInstanceUUID, processInstanceUUID);
        // Add to results
        result.add(jobData);
      }
    }
    // return results
    return result;
  }
}
