/**
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.jmx.commands;

import java.util.ArrayList;
import java.util.List;

import javax.xml.namespace.QName;

import org.ow2.orchestra.env.Environment;
import org.ow2.orchestra.facade.def.ProcessDefinition;
import org.ow2.orchestra.facade.def.ProcessState;
import org.ow2.orchestra.facade.def.full.ProcessFullDefinition;
import org.ow2.orchestra.facade.def.impl.ProcessDefinitionImpl;
import org.ow2.orchestra.services.Querier;
import org.ow2.orchestra.services.commands.Command;
import org.ow2.orchestra.util.EnvTool;

public final class FindProcessDefinitionsCommand implements Command<List<ProcessDefinition>> {

  private static final long serialVersionUID = 7939041300740473575L;
  private final ProcessState state;
  private final QName processName;

  public FindProcessDefinitionsCommand(final ProcessState state, final QName processName) {
    this.state = state;
    this.processName = processName;
  }
  public FindProcessDefinitionsCommand(final ProcessState state) {
    this.state = state;
    this.processName = null;
  }
  public FindProcessDefinitionsCommand(final QName processName) {
    this.state = null;
    this.processName = processName;
  }
  public FindProcessDefinitionsCommand() {
    this.state = null;
    this.processName = null;
  }
  public List<ProcessDefinition> execute(final Environment environment) {
    final List<ProcessDefinition> result = new ArrayList<ProcessDefinition>();
    final Querier querier = EnvTool.getQuerier();
    List<ProcessFullDefinition> processFullDefinitions;
    if (this.processName != null && this.state != null) {
      processFullDefinitions = querier.findProcessDefinitions(this.processName, this.state);
    } else if (this.processName != null) {
      processFullDefinitions = querier.findProcessDefinitions(this.processName);
    } else if (this.state != null) {
      processFullDefinitions = querier.findProcessDefinitions(this.state);
    } else {
      processFullDefinitions = querier.findProcessDefinitions();
    }
    for (final ProcessFullDefinition processFullDefinition : processFullDefinitions) {
      result.add(new ProcessDefinitionImpl(processFullDefinition));
    }
    return result;
  }
}
