/**
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.jmx.commands;

import java.util.HashSet;
import java.util.Set;

import org.ow2.orchestra.definition.BpelProcess;
import org.ow2.orchestra.definition.Node;
import org.ow2.orchestra.definition.activity.AbstractActivity;
import org.ow2.orchestra.env.Environment;
import org.ow2.orchestra.facade.data.def.ActivityDefinitionData;
import org.ow2.orchestra.facade.exception.OrchestraWrapperException;
import org.ow2.orchestra.facade.exception.ProcessNotFoundException;
import org.ow2.orchestra.facade.uuid.ProcessDefinitionUUID;
import org.ow2.orchestra.services.commands.Command;
import org.ow2.orchestra.util.EnvTool;

public class GetActivityDefinitionsCommand implements Command<Set<ActivityDefinitionData>> {

  private static final long serialVersionUID = -4282818977685054488L;

  private final ProcessDefinitionUUID processUUID;

  public GetActivityDefinitionsCommand(final ProcessDefinitionUUID processUUID) {
    this.processUUID = processUUID;
  }

  public Set<ActivityDefinitionData> execute(final Environment environment) {
    final BpelProcess bpelProcess = EnvTool.getRepository().getProcess(this.processUUID);
    if (bpelProcess == null) {
      throw new OrchestraWrapperException(new ProcessNotFoundException(this.processUUID));
    }
    final Set<ActivityDefinitionData> result = new HashSet<ActivityDefinitionData>();
    for (final Node node : bpelProcess.getNodes()) {
      final AbstractActivity activity = node.getBehaviour();
      result.add(activity.createDefinitionData(bpelProcess));
    }
    return result;
  }
}
