/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.runtime.op;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.ow2.orchestra.definition.Node;
import org.ow2.orchestra.definition.activity.AbstractActivity;
import org.ow2.orchestra.runtime.BpelExecution;
import org.ow2.orchestra.util.Misc;

public class ExecuteNode implements AtomicOperation {

  private static final Logger LOG = Logger.getLogger(ExecuteNode.class.getName());

  public void perform(final BpelExecution execution) {
    final Node node = execution.getNode();

    Misc.fastDynamicLog(ExecuteNode.LOG, Level.FINEST, "%s executing %s", execution, node);

    final AbstractActivity activity = node.getBehaviour();

    try {
      execution.setWaitForSignal(false);

      activity.execute(execution);

    } catch (final Exception e) {
      execution.handleException(node, e, execution.toString()
          + " couldn't execute " + activity + " for node " + node);
    }

    // if exception has been catched and exception handler has not disabled propagation,
    // then proceed.
    if (!execution.isWaitForSignal()) {
      execution.proceed();
    }
  }

  @Override
  public String toString() {
    return "execute(node)";
  }

}
