/**
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.services;

import java.util.ArrayList;
import java.util.List;

import org.ow2.orchestra.facade.runtime.full.ProcessFullInstance;

/**
 * This class represents a page of {@link ProcessFullInstance}s corresponding to
 * a requested {@link org.ow2.orchestra.facade.criteria.Criteria}.
 * 
 * @author Loic Albertin
 * 
 */
public class QuerierPagedResult<T> {

  /**
   * Returned set of {@link ProcessFullInstance}s for this page
   */
  private List<T> elements = new ArrayList<T>();

  /**
   * Total number of elements corresponding to requested {@link org.ow2.orchestra.facade.criteria.Criteria}
   * restrictions.
   */
  private long totalElementsCount = 0;

  public QuerierPagedResult() {
  }

  /**
   * @return Returns the set of {@link ProcessFullInstance}s for this page
   */
  public List<T> getElements() {
    return elements;
  }

  /**
   * @return Returns the total number of elements corresponding to requested
   *         {@link org.ow2.orchestra.facade.criteria.Criteria} restrictions.
   */
  public long getTotalElementsCount() {
    return totalElementsCount;
  }

  /**
   * @param totalElementsCount The totalElementsCount to set
   */
  public void setTotalElementsCount(long totalElementsCount) {
    this.totalElementsCount = totalElementsCount;
  }

}
