package org.ow2.orchestra.services.itf;

import java.util.List;
import java.util.Map;
import javax.xml.namespace.QName;
import org.ow2.orchestra.definition.element.InboundMessageElement;
import org.ow2.orchestra.facade.uuid.ProcessDefinitionUUID;
import org.ow2.orchestra.facade.uuid.ProcessInstanceUUID;
import org.ow2.orchestra.runtime.BpelExecution;
import org.ow2.orchestra.runtime.BpelInstance;
import org.ow2.orchestra.runtime.ScopeRuntime;
import org.ow2.orchestra.runtime.WaitingExecution;
import org.ow2.orchestra.services.ReceivingElement;
import org.ow2.orchestra.services.ResultIterator;
import org.ow2.orchestra.services.job.Job;
import org.ow2.orchestra.services.job.JobImpl;
import org.w3c.dom.Document;

/**
 * component that stores the process instances.
 *
 * @author Guillaume Porcher
 * @author Charles Souillard
 */
public interface InstanceRepository {

  /**
   *
   * @param process
   *            bpelExecution to store
   */
  void storeInstance(BpelInstance instance);

  void removeInstance(BpelInstance instance);

  void removeInstance(BpelInstance instance, boolean force);

  /**
   * @param child
   */
  void storeExecution(BpelExecution child);
  void removeExecution(BpelExecution child);


  void storeScopeRuntime(ScopeRuntime scopeRuntime);
  void removeScopeRuntime(ScopeRuntime scopeRuntime);

  void storeWaitingExecution(WaitingExecution waitingExecution);
  void removeWaitingExecution(WaitingExecution waitingExecution);


  /**
   * Returns one instance.
   */
  BpelInstance getInstance(ProcessInstanceUUID processInstanceUUID);
  /**
   * Returns the list of instances.
   */
  List<BpelInstance> getInstances();

  /**
   * Returns the list of instances for the given BPEL process.
   */
  List<BpelInstance> getInstances(QName processQName);
  List<BpelInstance> getInstances(ProcessDefinitionUUID processUUID);
  /**
   * Returns an up-to-date execution
   *
   * @param executionId
   *            execution
   */
  BpelExecution getUpdatedExecution(long executionId);

  ResultIterator<WaitingExecution> getWaitingExecutions(ReceivingElement receivingElement,
      Map<QName, Document> csProperties);
  WaitingExecution getFirstWaitingExecution(InboundMessageElement inboundMessageElement);

  /**
   * @return the list of jobs that have no retry left.
   */
  List<Job> findJobsWithException();

  /**
   * @param jobId
   * @return the job having this jobId
   */
  JobImpl< ? > getJob(long jobId);
}
