/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.services.jobexecutor.jdk;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.ow2.orchestra.services.commands.CommandService;
import org.ow2.orchestra.services.job.JobImpl;
import org.ow2.orchestra.services.jobexecutor.ExecuteJobCmd;
import org.ow2.orchestra.services.jobexecutor.JobExceptionHandler;
import org.ow2.orchestra.util.Misc;

/**
 * @author Guillaume Porcher
 *
 * Runnable task to execute a job in an ExecutorService
 */
public class JobExecutorTask implements Runnable {

  private static final Logger LOG = Logger.getLogger(JobExecutorTask.class.getName());

  private final CommandService commandService;
  private final JobImpl<?> job;

  public JobExecutorTask(final CommandService commandService, final JobImpl<?> job) {
    this.commandService = commandService;
    this.job = job;
  }

  public void run() {
    Misc.fastDynamicLog(JobExecutorTask.LOG, Level.FINEST, "job executor task executing job(s) %s", this.job);
    try {
      this.commandService.execute(new ExecuteJobCmd(this.job));
    } catch (final Exception e) {
      Misc.fastDynamicLog(JobExecutorTask.LOG, Level.FINEST, "exception while executing '%s': %s", this.job, e);
      this.commandService.execute(new JobExceptionHandler(this.job.getDbid(), e));
    }
  }

}
