package org.ow2.orchestra.util;

import java.util.ArrayList;
import java.util.List;

import org.ow2.orchestra.facade.exception.OrchestraRuntimeException;

/**
 * default implementation of the {@link Observable} interface.
 *
 * @author Tom Baeyens
 */
public class DefaultObservable implements Observable {

  protected List<Listener> listeners = null;

  public void addListener(final Listener listener) {
    if (listener == null) {
      throw new OrchestraRuntimeException("listener is null");
    }
    if (this.listeners == null) {
      this.listeners = new ArrayList<Listener>();
    }
    this.listeners.add(listener);
  }

  public void removeListener(final Listener listener) {
    if (listener == null) {
      throw new OrchestraRuntimeException("listener is null");
    }
    if (this.listeners != null) {
      this.listeners.remove(listener);
    }
  }

  public Listener addListener(final Listener listener, final String eventName) {
    if (eventName == null) {
      throw new OrchestraRuntimeException("eventName is null");
    }

    final List<String> eventNames = new ArrayList<String>();
    eventNames.add(eventName);

    return this.addListener(listener, eventNames);
  }

  public Listener addListener(final Listener listener, final List<String> eventNames) {
    if (listener == null) {
      throw new OrchestraRuntimeException("listener is null");
    }
    if (eventNames == null) {
      throw new OrchestraRuntimeException("eventNames is null");
    }
    final FilterListener filterListener = new FilterListener(listener, eventNames);
    this.addListener(filterListener);
    return filterListener;
  }

  public void fire(final String eventName) {
    this.fire(eventName, null);
  }

  public void fire(final String eventName, final Object info) {
    if (this.listeners != null) {
      for (final Listener listener : this.listeners) {
        listener.event(this, eventName, info);
      }
    }
  }

  public List<Listener> getListeners() {
    return this.listeners;
  }
}
